@@ -1,7 +1,7 @@
 #' @title RScript object
 #'
 #' @description Colored RScript object
-#' 
+#'
 #' @param file R script file. Not used if text is provided.
 #' @param text character vector. The text to parse. Not used if file is provided.
 #' @param comment.properties comment txtProperties object
@@ -41,69 +41,69 @@ RScript = function( file, text
 		, assignement.properties = textProperties( color = "black" )
 		, slot.properties = textProperties( color = "#F25774" )
 		, default.properties = textProperties( color = "black" )
-		, par.properties = parProperties() 
+		, par.properties = parProperties()
 		) {
-	
+
 	if( !inherits( par.properties, "parProperties" ) ){
 		stop("argument 'par.properties' must be an object of class 'parProperties'")
 	}
-	
+
 	if( !inherits(comment.properties, "textProperties") )
 		stop("argument comment.properties must be a textProperties object.")
-	
+
 	if( !inherits(roxygencomment.properties, "textProperties") )
 		stop("argument roxygencomment.properties must be a textProperties object.")
-	
+
 	if( !inherits(operators.properties, "textProperties") )
 		stop("argument operators.properties must be a textProperties object.")
-	
+
 	if( !inherits(keyword.properties, "textProperties") )
 		stop("argument keyword.properties must be a textProperties object.")
-	
+
 	if( !inherits(string.properties, "textProperties") )
 		stop("argument string.properties must be a textProperties object.")
-	
+
 	if( !inherits(number.properties, "textProperties") )
 		stop("argument number.properties must be a textProperties object.")
-	
+
 	if( !inherits(functioncall.properties, "textProperties") )
 		stop("argument functioncall.properties must be a textProperties object.")
-	
+
 	if( !inherits(argument.properties, "textProperties") )
 		stop("argument argument.properties must be a textProperties object.")
-	
+
 	if( !inherits(package.properties, "textProperties") )
 		stop("argument package.properties must be a textProperties object.")
-	
+
 	if( !inherits(formalargs.properties, "textProperties") )
 		stop("argument formalargs.properties must be a textProperties object.")
-	
+
 	if( !inherits(eqformalargs.properties, "textProperties") )
 		stop("argument eqformalargs.properties must be a textProperties object.")
-	
+
 	if( !inherits(assignement.properties, "textProperties") )
 		stop("argument assignement.properties must be a textProperties object.")
-	
+
 	if( !inherits(symbol.properties, "textProperties") )
 		stop("argument symbol.properties must be a textProperties object.")
-	
+
 	if( !inherits(slot.properties, "textProperties") )
 		stop("argument slot.properties must be a textProperties object.")
-	
+
 	if( !inherits(default.properties, "textProperties") )
 		stop("argument default.properties must be a textProperties object.")
-	
+
 	if( missing( file ) && missing( text ) )
 		stop("file OR text must be provided as argument.")
-	
+
 	if( !missing( file ) ){
 		if( !inherits( file, "character" ) )
 			stop("file must be a single character value")
 		if( length( file ) != 1 )
-			stop("file must be a single character value")		
+			stop("file must be a single character value")
 		if( !file.exists( file ) )
 			stop( file, " does not exist")
-		
+
 		pot.list = get.pots.from.script( file = file
 			, comment.properties = comment.properties
 			, roxygencomment.properties = roxygencomment.properties
@@ -126,8 +126,8 @@ RScript = function( file, text
 		if( !inherits( text, "character" ) )
 			stop("text must be a single character value")
 		if( length( text ) != 1 )
-			stop("text must be a single character value")		
-		
+			stop("text must be a single character value")
+
 		pot.list = get.pots.from.script( text = text
 			, comment.properties = comment.properties
 			, roxygencomment.properties = roxygencomment.properties
@@ -146,16 +146,16 @@ RScript = function( file, text
 			, default.properties = default.properties
 		)
 	}
-	
-	
+
+
 	jparProp = .jParProperties(par.properties)
-	
+
 	jRScript = .jnew(class.RScript, jparProp)
-	
-	for( i in 1:length(pot.list)){
+
+	for( i in seq_len(length(pot.list)) ){
 		.jcall( jRScript, "V", "addParagraph", .jpot(pot.list[[i]]) )
 	}
-	
+
 	out = list()
 	out$jobj = jRScript
 	class( out ) = c( "RScript", "set_of_paragraphs")
@@ -174,7 +174,7 @@ print.RScript = function(x, ...){
 #' @title get HTML code from a RScript object
 #'
 #' @description get HTML code from a RScript object
-#' 
+#'
 #' @param object the \code{RScript} object
 #' @param ... further arguments passed to other methods - not used.
 #' @return a character value
