@@ -304,16 +304,16 @@ public class ParProperties {
 			parProperties.put("background-color", shading_color.getrgba());
 		}
 		
-		if( marginleft > 0 ){
+		if( marginleft > -1 ){
 			parProperties.put("margin-left", marginleft + "pt");	
 		}
-		if( marginright > 0 ){
+		if( marginright > -1 ){
 			parProperties.put("margin-right", marginright + "pt");	
 		}
-		if( margintop > 0 ){
+		if( margintop > -1 ){
 			parProperties.put("margin-top", margintop + "pt");	
 		}
-		if( marginbottom > 0 ){
+		if( marginbottom > -1 ){
 			parProperties.put("margin-bottom", marginbottom + "pt");	
 		}
 		
